#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
wagtailsystemtext
----------
Simplified Wagtail system text management
"""

__title__ = 'wagtailsystemtext'
__version__ = '1.0.3'
__build__ = 103
__author__ = "Martin Sandström"
__license__ = "MIT"
__copyright__ = "Copyright 2016 Martin Sandström"

default_app_config = 'wagtailsystemtext.apps.WagtailSystemTextConfig'
