# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-12-20 14:50
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('wagtailcore', '0030_index_on_pagerevision_created_at'),
    ]

    operations = [
        migrations.CreateModel(
            name='SystemString',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('identifier', models.CharField(max_length=1024)),
                ('string', models.CharField(blank=True, max_length=1024, null=True)),
                ('group', models.CharField(default='general', max_length=255)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(blank=True, null=True)),
                ('accessed', models.DateTimeField(blank=True, null=True)),
                ('modified', models.BooleanField(default=False)),
                ('site', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.Site')),
            ],
        ),
        migrations.AlterUniqueTogether(
            name='systemstring',
            unique_together=set([('identifier', 'site', 'group')]),
        ),
    ]
